
/* 
   Project:     SOFTSUSY 
   File:        physpars.h
   Author:      Ben Allanach 
   Manual:      hep-ph/0104145, Comp. Phys. Comm. 143 (2002) 305 
   Webpage:     http://allanach.home.cern.ch/allanach/softsusy.html
   Description: Pole masses of sparticles and Higgs', mixing parameters

   $Log: physpars.h,v $
   Revision 1.2  2002/04/11 12:37:55  allanach
   *** empty log message ***

   Revision 1.3  2001/07/18 14:42:51  allanach
   Added proper header info
*/

#ifndef PHYSPARSH
#define PHYSPARSH

#include "linalg.h"

// Masses of the physical particles etc: We have made assumption that scalar
// mixing is small except in third generation and Higgs sector
struct sPhysical
{
  // in order: h^0, A^0, H^0, H^+-
  DoubleVector mhiggs;
  // sneutrino masses
  DoubleVector msnu;
  // chargino/neutralino masses: not ordered
  DoubleVector mch, mneut;
  double mGluino;
  // neutralino mixing
  DoubleMatrix mixNeut;
  // chargino and third famliy mixing angles
  double thetaL, thetaR, thetat, thetab, thetatau;
  // sparticle masses in order (i=L/R, family)
  DoubleMatrix mu, md, me;
  // Higgs mixing angle (alpha)
  double thetaH;
  
  // DRbar quantities evaluated at MSusy
  double t1OV1Ms, t2OV2Ms;
  
  // Feynman rules
  DoubleMatrix aChi0ChicW, bChi0ChicW;
  
  sPhysical();
  sPhysical(const sPhysical &);
  const sPhysical & operator = (const sPhysical &);
  void display(double *a) const;
}; 

ostream & operator <<(ostream &, const sPhysical &); 

struct sProblem
{
  bool noRhoConvergence;
  bool noConvergence;
  bool tachyon;
  bool muSqWrongSign;
  bool b;
  bool higgsUfb;
  bool nonperturbative;
  bool noMuConvergence;
  bool test() const 
  {return (noConvergence || tachyon || muSqWrongSign ||
	   higgsUfb || nonperturbative || noRhoConvergence || noMuConvergence);};
  
  sProblem();
  //  void displayverbose(ostream &);
  inline sProblem(const sProblem &);
  const sProblem & operator = (const sProblem &);
  
};
ostream & operator <<(ostream &st, const sProblem & p);
istream & operator >>(istream & left, sPhysical &s);

// ---------------------- inline class members ------------------------
inline sPhysical::sPhysical()
  : mhiggs(4), msnu(3), mch(2), mneut(4), mGluino(0.0),
    mixNeut(4, 4), thetaL(0.0), thetaR(0.0), thetat(0.0), thetab(0.0),
    thetatau(0.0), mu(2, 3), md(2, 3), me(2, 3), thetaH(0.0), 
    t1OV1Ms(0.0), t2OV2Ms(0.0), aChi0ChicW(4, 2), bChi0ChicW(4, 2)
{};

inline sPhysical::sPhysical(const sPhysical & s)
  : mhiggs(s.mhiggs), msnu(s.msnu), mch(s.mch), 
    mneut(s.mneut), mGluino(s.mGluino), mixNeut(s.mixNeut), thetaL(s.thetaL),
    thetaR(s.thetaR), thetat(s.thetat), thetab(s.thetab),
    thetatau(s.thetatau), mu(s.mu), md(s.md), me(s.me), thetaH(s.thetaH),
    t1OV1Ms(s.t1OV1Ms), t2OV2Ms(s.t2OV2Ms),
    aChi0ChicW(s.aChi0ChicW), bChi0ChicW(s.bChi0ChicW)
{};

inline sProblem::sProblem()
  : noRhoConvergence(false), noConvergence(false), tachyon(false), muSqWrongSign(false),
    b(false), higgsUfb(false), nonperturbative(false), noMuConvergence(false)
{}

inline sProblem::sProblem(const sProblem & s)
  : noRhoConvergence(s.noRhoConvergence), noConvergence(s.noConvergence),
    tachyon(s.tachyon), muSqWrongSign(s.muSqWrongSign), b(s.b),
    higgsUfb(s.higgsUfb), nonperturbative(s.nonperturbative), noMuConvergence(s.noMuConvergence)
{}

#endif
